package com.bonus.material.screen.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.screen.mapper.BmConfigMapper;
import com.bonus.material.screen.domain.BmConfig;
import com.bonus.material.screen.service.IBmConfigService;

/**
 * 功能参数配置Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-26
 */
@Service
public class BmConfigServiceImpl implements IBmConfigService 
{
    @Autowired
    private BmConfigMapper bmConfigMapper;

    /**
     * 查询功能参数配置
     * 
     * @param id 功能参数配置主键
     * @return 功能参数配置
     */
    @Override
    public BmConfig selectBmConfigById(Long id)
    {
        return bmConfigMapper.selectBmConfigById(id);
    }

    /**
     * 查询功能参数配置列表
     * 
     * @param bmConfig 功能参数配置
     * @return 功能参数配置
     */
    @Override
    public List<BmConfig> selectBmConfigList(BmConfig bmConfig)
    {
        return bmConfigMapper.selectBmConfigList(bmConfig);
    }

    /**
     * 新增功能参数配置
     * 
     * @param bmConfig 功能参数配置
     * @return 结果
     */
    @Override
    public int insertBmConfig(BmConfig bmConfig)
    {
        bmConfig.setCreateTime(DateUtils.getNowDate());
        return bmConfigMapper.insertBmConfig(bmConfig);
    }

    /**
     * 修改功能参数配置
     * 
     * @param bmConfig 功能参数配置
     * @return 结果
     */
    @Override
    public int updateBmConfig(BmConfig bmConfig)
    {
        bmConfig.setUpdateTime(DateUtils.getNowDate());
        return bmConfigMapper.updateBmConfig(bmConfig);
    }

    /**
     * 批量删除功能参数配置
     * 
     * @param ids 需要删除的功能参数配置主键
     * @return 结果
     */
    @Override
    public int deleteBmConfigByIds(Long[] ids)
    {
        return bmConfigMapper.deleteBmConfigByIds(ids);
    }

    /**
     * 删除功能参数配置信息
     * 
     * @param id 功能参数配置主键
     * @return 结果
     */
    @Override
    public int deleteBmConfigById(Long id)
    {
        return bmConfigMapper.deleteBmConfigById(id);
    }
}
