package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.basic.domain.BmConfig;
import com.bonus.material.basic.service.IBmConfigService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 功能参数配置Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "功能参数配置接口")
@RestController
@RequestMapping("/bm_config")
public class BmConfigController extends BaseController
{
    @Autowired
    private IBmConfigService bmConfigService;

    /**
     * 查询功能参数配置列表
     */
    @ApiOperation(value = "查询功能参数配置列表")
    @RequiresPermissions("basic:config:list")
    @GetMapping("/list")
    public TableDataInfo list(BmConfig bmConfig)
    {
        startPage();
        List<BmConfig> list = bmConfigService.selectBmConfigList(bmConfig);
        return getDataTable(list);
    }

    /**
     * 导出功能参数配置列表
     */
    @ApiOperation(value = "导出功能参数配置列表")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:config:export")
    @SysLog(title = "功能参数配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出功能参数配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmConfig bmConfig)
    {
        List<BmConfig> list = bmConfigService.selectBmConfigList(bmConfig);
        ExcelUtil<BmConfig> util = new ExcelUtil<BmConfig>(BmConfig.class);
        util.exportExcel(response, list, "功能参数配置数据");
    }

    /**
     * 获取功能参数配置详细信息
     */
    @ApiOperation(value = "获取功能参数配置详细信息")
    @RequiresPermissions("basic:config:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmConfigService.selectBmConfigById(id));
    }

    /**
     * 获取功能参数配置详细信息
     */
    @ApiOperation(value = "获取功能参数配置详细信息")
    @RequiresPermissions("basic:config:query")
    @GetMapping(value = "/{itemName}")
    public AjaxResult getInfoByName(@PathVariable("itemName") String itemName)
    {
        return success(bmConfigService.selectBmConfigByItemName(itemName));
    }

    /**
     * 新增功能参数配置
     */
    @ApiOperation(value = "新增功能参数配置")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:config:add")
    @SysLog(title = "功能参数配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增功能参数配置")
    @PostMapping
    public AjaxResult add(@RequestBody BmConfig bmConfig)
    {
        return toAjax(bmConfigService.insertBmConfig(bmConfig));
    }

    /**
     * 修改功能参数配置
     */
    @ApiOperation(value = "修改功能参数配置")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:config:edit")
    @SysLog(title = "功能参数配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改功能参数配置")
    @PutMapping
    public AjaxResult edit(@RequestBody BmConfig bmConfig)
    {
        return toAjax(bmConfigService.updateBmConfig(bmConfig));
    }

    /**
     * 删除功能参数配置
     */
    @ApiOperation(value = "删除功能参数配置")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:config:remove")
    @SysLog(title = "功能参数配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除功能参数配置")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmConfigService.deleteBmConfigByIds(ids));
    }
}
